@@ -1,5 +1,5 @@
 package Net::Whois::IANA;
-$Net::Whois::IANA::VERSION = '0.42';
+$Net::Whois::IANA::VERSION = '0.43';
 use 5.006;
 
 use strict;
@@ -473,7 +473,7 @@ sub arin_process_query (%) {
 	$query{status}  = $query{nettype};
 	$query{inetnum} = $query{netrange};
 	$query{source}  = 'ARIN';
-	if ($query{cidr} =~ /\,/) {
+	if ( defined $query{cidr} && $query{cidr} =~ /\,/) {
 		$query{cidr} = [split(/\, /,$query{cidr})];
 	}
 	else {
@@ -617,7 +617,7 @@ Net::Whois::IANA - Net::Whois::IANA - A universal WHOIS data extractor.
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
